==> xmdiary-3.0.1.tar.gz: xmdiary-3.0.1/dtools/xtmTools.h <==
/*----------------------------------------------------------------------------
--
--  Module:           xtmTools
--
--  Project:          Xdiary
--  System:           xtm - X Desktop Calendar
--    Subsystem:      <>
--    Function block: <>
--
--  Description:
--    Interface file for the xtmTools module.
--
--  Filename:         xtmTools.h
--
--  Authors:          Roger Larsson, Ulrika Bornetun
--  Creation date:    1990-12-16
--
--
--  (C) Copyright Ulrika Bornetun, Roger Larsson (1995)
--      All rights reserved
--
--  Permission to use, copy, modify, and distribute this software and its
--  documentation for any purpose and without fee is hereby granted,
--  provided that the above copyright notice appear in all copies. Ulrika
--  Bornetun and Roger Larsson make no representations about the usability
--  of this software for any purpose. It is provided "as is" without express
--  or implied warranty.
----------------------------------------------------------------------------*/

/* SCCS module identifier. */
/* SCCSID = @(#) Module: xtmTools.h, Version: 1.1, Date: 95/02/18 15:52:54 */


/* Only include this file once. */
#ifndef define_xtmTools_h
#  define define_xtmTools_h


/*----------------------------------------------------------------------------
--  Include files
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Macro definitions
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Type declarations
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Global definitions
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Function prototypes
----------------------------------------------------------------------------*/

void
xtmToInitializeResourceMapping( unsigned int  argc,
                                char**        argv,
                                Display*      display );

void
xtmToPlayMelody( Widget  parentW,
                 char    *tune_player,
                 char    *tune_player_param,
                 char    *tune_file,
                 int     volume,
                 int     duration_delta );

void
xtmToSessionMgmt( Widget        shellW,
                  unsigned int  argc,
                  char**        argv );

void
xtmToSetLocate( char  *program_name );

int
xtmToStartProcess( Widget   parent,
                   Boolean  remove_message,
                   char     *starting_message,
                   char     *process_args[] );

#endif

==> xmdiary-3.0.3.tar.gz: xmdiary-3.0.3/dtools/xtmTools.h <==
/*----------------------------------------------------------------------------
--
--  Module:           xtmTools
--
--  Project:          Xdiary
--  System:           xtm - X Desktop Calendar
--    Subsystem:      <>
--    Function block: <>
--
--  Description:
--    Interface file for the xtmTools module.
--
--  Filename:         xtmTools.h
--
--  Authors:          Roger Larsson, Ulrika Bornetun
--  Creation date:    1990-12-16
--
--
--  (C) Copyright Ulrika Bornetun, Roger Larsson (1995)
--      All rights reserved
--
--  Permission to use, copy, modify, and distribute this software and its
--  documentation for any purpose and without fee is hereby granted,
--  provided that the above copyright notice appear in all copies. Ulrika
--  Bornetun and Roger Larsson make no representations about the usability
--  of this software for any purpose. It is provided "as is" without express
--  or implied warranty.
----------------------------------------------------------------------------*/

/* SCCS module identifier. */
/* SCCSID = @(#) Module: xtmTools.h, Version: 1.1, Date: 95/02/18 15:52:54 */


/* Only include this file once. */
#ifndef define_xtmTools_h
#  define define_xtmTools_h


/*----------------------------------------------------------------------------
--  Include files
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Macro definitions
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Type declarations
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Global definitions
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
--  Function prototypes
----------------------------------------------------------------------------*/

void
xtmToInitializeResourceMapping( unsigned int  argc,
                                char**        argv,
                                Display*      display );

void
xtmToPlayMelody( Widget  parentW,
                 char    *tune_player,
                 char    *tune_player_param,
                 char    *tune_file,
                 int     volume,
                 int     duration_delta );

void
xtmToSessionMgmt( Widget        shellW,
                  unsigned int  argc,
                  char**        argv );

void
xtmToSetLocale( char  *program_name );

int
xtmToStartProcess( Widget   parent,
                   Boolean  remove_message,
                   char     *starting_message,
                   char     *process_args[] );

#endif
